Module: Gamefic::Scripting::Hooks
- Included in:
- Gamefic::Scripting
- Defined in:
- lib/gamefic/scripting/hooks.rb
Overview
Scripting hook methods are instance methods that return callbacks for execution in the context of a scriptable module or narrative. They collect the procs defined in Scriptable hook methods and bind them to the instance for execution.
Instance Method Summary collapse
- #after_commands ⇒ Array<Binding>
- #before_commands ⇒ Array<Binding>
- #conclude_blocks ⇒ Array<Binding>
- #player_conclude_blocks ⇒ Array<Binding>
- #player_output_blocks ⇒ Array<Binding>
- #ready_blocks ⇒ Array<Binding>
- #update_blocks ⇒ Array<Binding>
Instance Method Details
#after_commands ⇒ Array<Binding>
17 18 19 |
# File 'lib/gamefic/scripting/hooks.rb', line 17 def after_commands find_and_bind(:after_commands) end |
#before_commands ⇒ Array<Binding>
12 13 14 |
# File 'lib/gamefic/scripting/hooks.rb', line 12 def before_commands find_and_bind(:before_commands) end |
#conclude_blocks ⇒ Array<Binding>
37 38 39 |
# File 'lib/gamefic/scripting/hooks.rb', line 37 def conclude_blocks find_and_bind(:conclude_blocks) end |
#player_conclude_blocks ⇒ Array<Binding>
42 43 44 |
# File 'lib/gamefic/scripting/hooks.rb', line 42 def player_conclude_blocks find_and_bind(:player_conclude_blocks) end |
#player_output_blocks ⇒ Array<Binding>
32 33 34 |
# File 'lib/gamefic/scripting/hooks.rb', line 32 def player_output_blocks find_and_bind(:player_output_blocks) end |